@@ -8,6 +8,7 @@
 #' @param t.cycle Define the period of the environmental cycle or a single day in hours. This defaults to 24.
 #' @param ind The channel number (or individual) whose actogram must be plotted.
 #' @param key.acto Key for reactive input tables in the shiny app.
+#' @param color Color of actograms in rgb format. The input for this must be a vector with 4 values, i.e., r,g,b,transparency. The values for r,g,b can only be between 0 and 1. 0,0,0 would be black and 1,1,1 would be white. Transparency values can also go from 0 to 1, 0 being fully transparent and 1 being fully opaque.
 #'
 #' @importFrom zoo rollapply
 #' @importFrom plotly plot_ly add_trace layout %>% subplot
@@ -27,7 +28,7 @@
 #' }
 
 
-indActogram <- function(data, bin = 30, t.cycle = 24, ind = 1, key.acto = 1) {
+indActogram <- function(data, bin = 30, t.cycle = 24, ind = 1, key.acto = 1, color = rgb(0,0,0,1)) {
 
   requireNamespace("plotly")
   requireNamespace("zoo")
@@ -65,9 +66,9 @@ indActogram <- function(data, bin = 30, t.cycle = 24, ind = 1, key.acto = 1) {
         y = a[,j]/max(a[,j]),
         type = "bar",
         marker = list(
-          color = "green",
+          color = color,
           line = list(
-            color = "green"
+            color = color
           )
         ),
         source = "actogram.phases",
